==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Insertar una À',
	'barre_adresse' => 'Dirección',
	'barre_aide' => 'Puedes enriquecer el formato de tu texto utilizando &quot;atajos tipográficos&quot;',
	'barre_alignerdroite' => '[/Alinear a derecha/] el párrafo',
	'barre_ancres' => 'Anclas',
	'barre_barre' => 'Tachar el texto',
	'barre_bulle' => 'Globo de ayuda',
	'barre_c_cedille_maj' => 'Insertar una Ç',
	'barre_cadre' => 'Mostrar dentro de una  &lt;cadre&gt;caja de texto&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracteres especiales',
	'barre_centrer' => '[|Centrar|] párrafo',
	'barre_chercher' => 'Buscar y reemplazar',
	'barre_clean' => 'Limpiar el código de todas las etiquetas HTML',
	'barre_code' => 'Mostrar como &lt;code&gt;código fuente&lt;/code&gt;',
	'barre_desindenter' => 'Deshacer sublista',
	'barre_e_accent_aigu' => 'Insertar una É',
	'barre_e_accent_grave' => 'Intertar una È',
	'barre_ea' => 'Insertar una æ',
	'barre_ea_maj' => 'Insertar una Æ',
	'barre_encadrer' => '[(Párrafo con recuadro)]',
	'barre_eo' => 'Insertar una œ',
	'barre_eo_maj' => 'Insertar  una Œ',
	'barre_euro' => 'Insertar el símbolo € ',
	'barre_exposant' => 'Poner el texto en &lt;sup&gt;superíndice&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formateado especial',
	'barre_galerie' => 'Abrir la galería',
	'barre_gestion_anc_bulle' => 'Globo de ayuda de anclas',
	'barre_gestion_anc_caption' => 'Gestionar las anclas',
	'barre_gestion_anc_cible' => 'Destino del ancla',
	'barre_gestion_anc_inserer' => 'Convertir a un ancla',
	'barre_gestion_anc_nom' => 'Nombre del ancla',
	'barre_gestion_anc_pointer' => 'Apuntar a un ancla',
	'barre_gestion_caption' => 'Leyenda y resumen',
	'barre_gestion_colonne' => 'Núm de columnas',
	'barre_gestion_cr_casse' => 'Respetar mayúsculas y minúsculas',
	'barre_gestion_cr_changercasse' => 'Alternar',
	'barre_gestion_cr_changercassemajuscules' => 'Pasar a mayúsculas',
	'barre_gestion_cr_changercasseminuscules' => 'Pasar a minúsculas',
	'barre_gestion_cr_chercher' => 'Buscar',
	'barre_gestion_cr_entier' => 'Sólo palabras completas',
	'barre_gestion_cr_remplacer' => 'Reemplazar',
	'barre_gestion_cr_tout' => 'Reemplazar todo',
	'barre_gestion_entete' => 'Encabezado',
	'barre_gestion_ligne' => 'Núm de líneas',
	'barre_gestion_taille' => 'Tamaño fijo',
	'barre_glossaire' => '[?Referencia] (Wikipedia)',
	'barre_gras' => '{{Negrita}}',
	'barre_guillemets' => 'Encerrar entre «comillas dobles«',
	'barre_guillemets_simples' => 'Place between “single quotes“',
	'barre_indenter' => 'Convertir en sublista',
	'barre_inserer_cadre' => 'Inseretar un código preformatado (marco)',
	'barre_inserer_caracteres' => 'Insertar caracteres especiales',
	'barre_inserer_code' => 'Insertar un código informático (código)',
	'barre_intertitre' => 'Convertir en {{{intertítulo}}}',
	'barre_italic' => '{cursiva}',
	'barre_langue' => 'Idioma abreviado',
	'barre_lien' => 'Convertir en [hipevínculo->http://...]',
	'barre_lien_externe' => 'Enlace externo',
	'barre_lien_input' => 'Por favor ingresa el destino de tu hipervínculo (puede ser una URL de la forma http://www.misitio.com o simplmente el número de un artículo de este sitio).',
	'barre_liste_ol' => 'Convertir en lista ordenada',
	'barre_liste_ul' => 'Convertir en lista',
	'barre_lorem_ipsum' => 'Insertar un párrafo ficticio',
	'barre_lorem_ipsum_3' => 'Insertar tres párrafos ficticios',
	'barre_miseenevidence' => 'Resaltar el [*texto*]',
	'barre_note' => 'Convertir en [[Nota al pie]]',
	'barre_paragraphe' => 'Crear párrafo',
	'barre_petitescapitales' => 'Poner el texto en &lt;sc&gt;mayúsculas pequeñas&lt;/sc&gt;',
	'barre_poesie' => 'Mostrar como &lt;poesie&gt;Poesía&lt;/poesie&gt;',
	'barre_preview' => 'Modo previsualización',
	'barre_quote' => '<quote>Citar</quote>',
	'barre_stats' => 'Mostrar estadística del texto',
	'barre_tableau' => 'Insertar/modificar una tabla (seleccionala primero)',

	// C
	'config_info_enregistree' => 'Configuración guardada',

	// E
	'editer' => 'Editar',
	'explication_barre_outils_public' => 'Los scripts CSS y Javascript de las barras de herramientas (extensión Porta Pluma) se cargan en el espacio público y permiten utilizar estas barras en los formularios de foros, el "lápiz" público o para otros plugins, si sus respectivas configuraciones lo preven.',
	'explication_barre_outils_public_2' => 'Puedes elegir no cargar estos scripts para alivianar el tamaño de las páginas públicas.
Si es así, sea cual sea la configuración de los foros, lápiz, u otro plugin, ninguna barra de herramientas podrá estar presente automáticamente en el espacio público.',

	// I
	'info_barre_outils_public' => 'Barra de herramientas pública',
	'info_porte_plume_titre' => 'Configurar las barras de herramientas',

	// L
	'label_barre_outils_public_non' => 'No cargar los scripts de la barra de herramientas en el espacio público. ',
	'label_barre_outils_public_oui' => 'CArgar los scripts de las barras de herramientas en el espacio público',

	// V
	'voir' => 'Ver'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Insertar una À',
	'barre_adresse' => 'Dirección',
	'barre_aide' => 'Puedes enriquecer el formato de tu texto utilizando &quot;atajos tipográficos&quot;',
	'barre_alignerdroite' => '[/Alinear a derecha/] el párrafo',
	'barre_ancres' => 'Anclas',
	'barre_barre' => 'Tachar el texto',
	'barre_bulle' => 'Globo de ayuda',
	'barre_c_cedille_maj' => 'Insertar una Ç',
	'barre_cadre' => 'Mostrar dentro de una  &lt;cadre&gt;caja de texto&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracteres especiales',
	'barre_centrer' => '[|Centrar|] párrafo',
	'barre_chercher' => 'Buscar y reemplazar',
	'barre_clean' => 'Limpiar el código de todas las etiquetas HTML',
	'barre_code' => 'Mostrar como &lt;code&gt;código fuente&lt;/code&gt;',
	'barre_desindenter' => 'Deshacer sublista',
	'barre_e_accent_aigu' => 'Insertar una É',
	'barre_e_accent_grave' => 'Intertar una È',
	'barre_ea' => 'Insertar una æ',
	'barre_ea_maj' => 'Insertar una Æ',
	'barre_encadrer' => '[(Párrafo con recuadro)]',
	'barre_eo' => 'Insertar una œ',
	'barre_eo_maj' => 'Insertar  una Œ',
	'barre_euro' => 'Insertar el símbolo € ',
	'barre_exposant' => 'Poner el texto en &lt;sup&gt;superíndice&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formateado especial',
	'barre_galerie' => 'Abrir la galería',
	'barre_gestion_anc_bulle' => 'Globo de ayuda de anclas',
	'barre_gestion_anc_caption' => 'Gestionar las anclas',
	'barre_gestion_anc_cible' => 'Destino del ancla',
	'barre_gestion_anc_inserer' => 'Convertir a un ancla',
	'barre_gestion_anc_nom' => 'Nombre del ancla',
	'barre_gestion_anc_pointer' => 'Apuntar a un ancla',
	'barre_gestion_caption' => 'Leyenda y resumen',
	'barre_gestion_colonne' => 'Núm de columnas',
	'barre_gestion_cr_casse' => 'Respetar mayúsculas y minúsculas',
	'barre_gestion_cr_changercasse' => 'Alternar',
	'barre_gestion_cr_changercassemajuscules' => 'Pasar a mayúsculas',
	'barre_gestion_cr_changercasseminuscules' => 'Pasar a minúsculas',
	'barre_gestion_cr_chercher' => 'Buscar',
	'barre_gestion_cr_entier' => 'Sólo palabras completas',
	'barre_gestion_cr_remplacer' => 'Reemplazar',
	'barre_gestion_cr_tout' => 'Reemplazar todo',
	'barre_gestion_entete' => 'Encabezado',
	'barre_gestion_ligne' => 'Núm de líneas',
	'barre_gestion_taille' => 'Tamaño fijo',
	'barre_glossaire' => '[?Referencia] (Wikipedia)',
	'barre_gras' => '{{Negrita}}',
	'barre_guillemets' => 'Encerrar entre «comillas dobles«',
	'barre_guillemets_simples' => 'Place between “single quotes“',
	'barre_indenter' => 'Convertir en sublista',
	'barre_inserer_cadre' => 'Insertar un código preformateado (marco)',
	'barre_inserer_caracteres' => 'Insertar caracteres especiales',
	'barre_inserer_code' => 'Insertar un código informático (código)',
	'barre_intertitre' => 'Convertir en {{{intertítulo}}}',
	'barre_italic' => '{cursiva}',
	'barre_langue' => 'Idioma abreviado',
	'barre_lien' => 'Convertir en [hipevínculo->http://...]',
	'barre_lien_externe' => 'Enlace externo',
	'barre_lien_input' => 'Por favor ingresa el destino de tu hipervínculo (puede ser una URL de la forma http://www.misitio.com o simplmente el número de un artículo de este sitio).',
	'barre_liste_ol' => 'Convertir en lista ordenada',
	'barre_liste_ul' => 'Convertir en lista',
	'barre_lorem_ipsum' => 'Insertar un párrafo ficticio',
	'barre_lorem_ipsum_3' => 'Insertar tres párrafos ficticios',
	'barre_miseenevidence' => 'Resaltar el [*texto*]',
	'barre_note' => 'Convertir en [[Nota al pie]]',
	'barre_paragraphe' => 'Crear párrafo',
	'barre_petitescapitales' => 'Poner el texto en &lt;sc&gt;mayúsculas pequeñas&lt;/sc&gt;',
	'barre_poesie' => 'Mostrar como &lt;poesie&gt;Poesía&lt;/poesie&gt;',
	'barre_preview' => 'Modo previsualización',
	'barre_quote' => '<quote>Citar</quote>',
	'barre_stats' => 'Mostrar estadística del texto',
	'barre_tableau' => 'Insertar/modificar una tabla (seleccionala primero)',

	// C
	'config_info_enregistree' => 'Configuración guardada',

	// E
	'editer' => 'Editar',
	'explication_barre_outils_public' => 'Los scripts CSS y Javascript de las barras de herramientas (extensión Porta Pluma) se cargan en el espacio público y permiten utilizar estas barras en los formularios de foros, el "lápiz" público o para otros plugins, si sus respectivas configuraciones lo preven.',
	'explication_barre_outils_public_2' => 'Puedes elegir no cargar estos scripts para alivianar el tamaño de las páginas públicas.
Si es así, sea cual sea la configuración de los foros, lápiz, u otro plugin, ninguna barra de herramientas podrá estar presente automáticamente en el espacio público.',

	// I
	'info_barre_outils_public' => 'Barra de herramientas pública',
	'info_porte_plume_titre' => 'Configurar las barras de herramientas',

	// L
	'label_barre_outils_public_non' => 'No cargar los scripts de la barra de herramientas en el espacio público. ',
	'label_barre_outils_public_oui' => 'CArgar los scripts de las barras de herramientas en el espacio público',

	// V
	'voir' => 'Ver'
);
